@@ -1,6 +1,6 @@
 -- tkz_elements-main.lua
--- date 2024/02/04
--- version 2.00c
+-- date 2024/04/27
+-- version 2.25c
 -- Copyright 2024  Alain Matthes
 -- This work may be distributed and/or modified under the
 -- conditions of the LaTeX Project Public License, either version 1.3
@@ -16,8 +16,8 @@
  C  = {}
  E  = {}
  L  = {}
- M  = {}
  P  = {}
+ M  = {} 
  Q  = {}
  R  = {}
  RP = {}
@@ -47,3 +47,5 @@ require "tkz_elements_functions_lines.lua"
 require "tkz_elements_functions_circles.lua"
 require "tkz_elements_functions_triangles.lua"
 require "tkz_elements_functions_regular.lua"
+require "tkz_elements_functions_matrices.lua"
+require "tkz_elements_matrices.lua"
\ No newline at end of file
